# -*- rpm-spec -*-

# Note: This spec file is largely shared with the public virtio-win drivers
# shipped on fedora sites. The canonical location is here:
#
# https://github.com/crobinso/virtio-win-pkg-scripts
#
# If you make any changes to this file that affect the RPM content (but not
# version numbers or changelogs, etc), submit a patch them to the upstream
# spec file.

%global virtio_win_prewhql_build virtio-win-prewhql-0.1-104
%global qemu_ga_win_build qemu-ga-win-7.0-10
%global qxl_build qxl-win-unsigned-0.1-20
# qxlwddm is fedora only for now
%global qxlwddm_build qxlwddm-0.1-11

Summary: VirtIO para-virtualized drivers for Windows(R)
Name: virtio-win
Version: 0.1.104
Release: 1
Group: Applications/System
URL: http://www.redhat.com/
BuildArch: noarch

%if 0%{?rhel}
# RHEL RPM ships WHQL signed drivers, which are under a proprietary license
# qemu-ga builds are GPLv2
License: Red Hat Proprietary and GPLv2
%else
# virtio-win: https://github.com/YanVugenfirer/kvm-guest-drivers-windows/blob/master/LICENSE
# qxl: http://cgit.freedesktop.org/spice/win32/qxl/tree/xddm/COPYING
# qxldod: https://github.com/vrozenfe/qxl-dod/blob/master/LICENSE
# qemu-ga: http://git.qemu.org/?p=qemu.git;a=blob;f=COPYING
License: GPLv2
%endif

# Already built files
Source1: %{name}-%{version}-bin-for-rpm.tar.gz
Source2: %{qemu_ga_win_build}-installers.zip

# Source files shipped in the srpm
Source3: %{virtio_win_prewhql_build}-sources.zip
Source4: %{qemu_ga_win_build}-sources.zip
Source5: %{qxl_build}-sources.zip
%if 0%{?fedora}
Source6: %{qxlwddm_build}-sources.zip
%endif

BuildRequires: /usr/bin/mkisofs


%description
VirtIO para-virtualized Windows(R) drivers for 32-bit and 64-bit
Windows(R) guests.


%prep
%setup -q -T -b 1 -n %{name}-%{version}
%setup -q -T -a 2 -n %{name}-%{version} -D


%build
%{__mv} %{qemu_ga_win_build} guest-agent

# Generate .iso
/usr/bin/mkisofs -m vfddrivers -o %{name}-%{version}.iso -r -J \
  -input-charset iso8859-1 -V "%{name}-%{version}" .


%install
%{__install} -d -m0755 %{buildroot}%{_datadir}/%{name}

# Install .iso, create non-versioned symlink
%{__install} -p -m0644 %{name}-%{version}.iso %{buildroot}%{_datadir}/%{name}
%{__ln_s} %{name}-%{version}.iso %{buildroot}%{_datadir}/%{name}/%{name}.iso

# Install .vfd files, create non-versioned symlinks
%{__install} -p -m0644 %{name}-%{version}_x86.vfd  %{buildroot}%{_datadir}/%{name}
%{__ln_s} %{name}-%{version}_x86.vfd %{buildroot}%{_datadir}/%{name}/%{name}_x86.vfd
%{__install} -p -m0644 %{name}-%{version}_amd64.vfd  %{buildroot}%{_datadir}/%{name}
%{__ln_s} %{name}-%{version}_amd64.vfd %{buildroot}%{_datadir}/%{name}/%{name}_amd64.vfd

%{__cp} -a vfddrivers %{buildroot}/%{_datadir}/%{name}/drivers
%{__cp} -a guest-agent %{buildroot}/%{_datadir}/%{name}


%files
%doc virtio-win_license.txt
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/%{name}-%{version}.iso
%{_datadir}/%{name}/%{name}.iso
%{_datadir}/%{name}/*.vfd
%{_datadir}/%{name}/drivers
%{_datadir}/%{name}/guest-agent


%changelog
* Mon May 25 2015 Cole Robinson <crobinso@redhat.com> - 0.1.104-1
- Update to virtio-win-prewhql-0.1-104
- BZ 1214568 vioscsi Add WMI facility to check the virito-scsi mq enabled
- BZ 1172920 vioser  bsod on shutdown after device was unplugged
- BZ 954183  NetKVM  Clean-up SDV run results during clean.bat execution
- BZ 1067249 balloon device can't be removed when service is running
- BZ 1190960 NetKVM  [mq]job failed due to "Received some net buffer lists out of order" w/ 4 queues
- BZ 1067225 viostor Windows guest performing out-of-bounds accesses on virtio device
- BZ 1195487 viostor Windows guest performing out-of-bounds accesses on virtio device


* Tue May 05 2015 Cole Robinson <crobinso@redhat.com> - 0.1.103-2
- Distribute the pre-release pvpanic driver
- Distribute the pre-release qxlwddm/qxldod driver
- Distribute qemupciserial.cat

* Fri May 01 2015 Cole Robinson <crobinso@redhat.com> - 0.1.103-1
- Update to virtio-win-prewhql-0.1-103
- BZ 1210166 vioscsi - Add multiqueue support to Windows virtio-scsi driver.
- BZ 954183  NetKVM - Static driver verifier fails with NetKVM
- BZ 1190960 NetKVM - job failed due to "Received some net buffer lists out of order" w/ 4 queues
- BZ 1190968 NetKVM - job "NDISTest 6.0 - [1 Machine] - 1c_Mini6RSSOids" last for hours and never stop w/ 4 queues
- BZ 996479  pvpanic - RFE:pvpanic driver for windows guest
- pvpanic driver isn't shipped yet since it has barely been tested
- Reduce .iso and RPM size by hardlinking identical files (bz 1217644)
- Ship QXL on the .iso (bz 1217642)

* Sun Apr 26 2015 Cole Robinson <crobinso@redhat.com> - 0.1.102-1
- Update to virtio-win-prewhql-0.1-102

* Sun Apr 26 2015 Cole Robinson <crobinso@redhat.com> - 0.1.101-1
- Update to virtio-win-prewhql-0.1-101

* Sun Apr 26 2015 Cole Robinson <crobinso@redhat.com> - 0.1.100-1
- Update to virtio-win-prewhql-0.1-100

* Sun Apr 26 2015 Cole Robinson <crobinso@redhat.com> - 0.1.96-1
- Update to virtio-win-prewhql-0.1-96
